@@ -201,7 +201,7 @@ original message cannot get undeleted after the move.
 
 =option  shallow_head BOOLEAN
 =default shallow_head false
-Only the head uses is reused, not the body.  This is probably a bad choice,
+Only the head is reused, not the body.  This is probably a bad choice,
 because the header fields can be updated, for instance when labels change.
 
 =option  shallow_body BOOLEAN
@@ -528,7 +528,7 @@ or better:
 =cut
 
 sub study($)
-{	my $head = $_[0]->head or return;
+{	my $head = shift->head or return;
 	scalar $head->study(@_);    # return only last
 }
 
